@@ -306,8 +306,8 @@ class Botoy:
                 else:
                     return
         # 传递几个数据供(插件中的)接收函数调用, 其他不再注释
-        context._host = self.config.host
-        context._port = self.config.port
+        setattr(context, "_host", self.config.host)
+        setattr(context, "_port", self.config.port)
         self.pool.submit(self._friend_context_distributor, context)
 
     def _group_msg_handler(self, msg):
@@ -329,8 +329,8 @@ class Botoy:
                     context = new_context
                 else:
                     return
-        context._host = self.config.host
-        context._port = self.config.port
+        setattr(context, "_host", self.config.host)
+        setattr(context, "_port", self.config.port)
         self.pool.submit(self._group_context_distributor, context)
 
     def _event_handler(self, msg):
@@ -346,8 +346,8 @@ class Botoy:
                     context = new_context
                 else:
                     return
-        context._host = self.config.host
-        context._port = self.config.port
+        setattr(context, "_host", self.config.host)
+        setattr(context, "_port", self.config.port)
         self.pool.submit(self._event_context_distributor, context)
 
     ########################################################################
