@@ -9,7 +9,7 @@ from botoy.model import GroupMsg
 @functools.lru_cache(520)
 def __get_group_admins(qq, host, port, group):
     admins = Action(qq=qq, port=port, host=host).getGroupAdminList(group, True)
-    return [admin['MemberUin'] for admin in admins]
+    return [admin["MemberUin"] for admin in admins]
 
 
 def from_admin(func=None):
